@@ -1,54 +1,10 @@
 package Dist::Zilla::PluginBundle::Author::OALDERS;
-$Dist::Zilla::PluginBundle::Author::OALDERS::VERSION = '0.000014';
+$Dist::Zilla::PluginBundle::Author::OALDERS::VERSION = '0.000015';
 use Moose;
 use namespace::autoclean;
 
 use feature qw( say );
 
-use Dist::Zilla::Plugin::AutoPrereqs;
-use Dist::Zilla::Plugin::CPANFile;
-use Dist::Zilla::Plugin::CheckChangesHasContent;
-use Dist::Zilla::Plugin::ConfirmRelease;
-use Dist::Zilla::Plugin::ContributorsFile;
-use Dist::Zilla::Plugin::CopyFilesFromBuild;
-use Dist::Zilla::Plugin::CopyFilesFromRelease;
-use Dist::Zilla::Plugin::ExecDir;
-use Dist::Zilla::Plugin::Git::Check;
-use Dist::Zilla::Plugin::Git::Commit;
-use Dist::Zilla::Plugin::Git::Contributors;
-use Dist::Zilla::Plugin::Git::GatherDir;
-use Dist::Zilla::Plugin::Git::Push;
-use Dist::Zilla::Plugin::Git::Tag;
-use Dist::Zilla::Plugin::GithubMeta;
-use Dist::Zilla::Plugin::InstallGuide;
-use Dist::Zilla::Plugin::License;
-use Dist::Zilla::Plugin::MAXMIND::TidyAll;
-use Dist::Zilla::Plugin::MakeMaker;
-use Dist::Zilla::Plugin::Manifest;
-use Dist::Zilla::Plugin::ManifestSkip;
-use Dist::Zilla::Plugin::MetaJSON;
-use Dist::Zilla::Plugin::MetaConfig;
-use Dist::Zilla::Plugin::MetaNoIndex;
-use Dist::Zilla::Plugin::MetaResources;
-use Dist::Zilla::Plugin::MetaYAML;
-use Dist::Zilla::Plugin::MinimumPerl;
-use Dist::Zilla::Plugin::PkgVersion;
-use Dist::Zilla::Plugin::PodCoverageTests;
-use Dist::Zilla::Plugin::PodWeaver;
-use Dist::Zilla::Plugin::Prereqs;
-use Dist::Zilla::Plugin::PromptIfStale;
-use Dist::Zilla::Plugin::PruneCruft;
-use Dist::Zilla::Plugin::ReadmeAnyFromPod;
-use Dist::Zilla::Plugin::RunExtraTests;
-use Dist::Zilla::Plugin::ShareDir;
-use Dist::Zilla::Plugin::Test::CPAN::Changes;
-use Dist::Zilla::Plugin::Test::PodSpelling;
-use Dist::Zilla::Plugin::TestRelease;
-use Dist::Zilla::Plugin::Test::ReportPrereqs;
-use Dist::Zilla::Plugin::Test::Synopsis;
-use Dist::Zilla::Plugin::Test::TidyAll;
-use Dist::Zilla::Plugin::TravisCI::StatusBadge;
-use Dist::Zilla::Plugin::UploadToCPAN;
 use List::AllUtils qw( first );
 use Pod::Elemental::Transformer::List;
 use Types::Path::Tiny qw( Path );
@@ -57,6 +13,7 @@ use Types::Standard qw( ArrayRef Maybe Str );
 with(
     'Dist::Zilla::Role::PluginBundle::Easy',
     'Dist::Zilla::Role::PluginBundle::PluginRemover',
+    'Dist::Zilla::Role::PluginBundle::Config::Slicer',    # needs to come last
 );
 
 has stopwords => (
@@ -149,8 +106,12 @@ sub configure {
             }
         ],
 
-        [ 'GithubMeta'     => { issues           => 1 } ],
-        [ 'Git::GatherDir' => { exclude_filename => \@copy_from_build } ],
+        [ 'GithubMeta' => { issues => 1 } ],
+        [
+            'Git::GatherDir' => {
+                exclude_filename => [ @copy_from_build, @copy_from_release ]
+            }
+        ],
         [ 'CopyFilesFromRelease' => { filename    => [@copy_from_release] } ],
         [ 'Git::Check'           => { allow_dirty => \@allow_dirty } ],
         [
@@ -215,7 +176,7 @@ Dist::Zilla::PluginBundle::Author::OALDERS - A plugin bundle for distributions b
 
 =head1 VERSION
 
-version 0.000014
+version 0.000015
 
 =head2 configure
 
